@@ -6,7 +6,7 @@ use warnings;
 use Time::Local;
 
 our $ERROR;
-our $VERSION = '1.20_02';
+our $VERSION = '1.20_03';
 
 sub new {
     my ( $class, $date ) = @_;
@@ -408,7 +408,7 @@ sub as_string {
 		   10 => "The Dawnless Day, 1419.\n" .
 		       "The Rohirrim are mustered and ride from Harrowdale, 1419.\n" .
 		       "Faramir rescued by Gandalf at the gates of Minas Tirith, 1419.\n" .
-		       "An army from the Morannon takes Cair Andros and passes in Anorien, 1419.\n",
+		       "An army from the Morannon takes Cair Andros and passes into Anorien, 1419.\n",
 		   11 => "Gollum visits Shelob, 1419.\n" .
 		       "Denethor sends Faramir to Osgiliath, 1419.\n" .
 		       "Eastern Rohan is invaded and Lorien assaulted, 1419.\n",
@@ -714,7 +714,7 @@ you I'll consider changing it :-)
 
 =head1 NOTE: YEAR CALCULATION
 
-L<http://www.glyhweb.com/arda/f/fourthage.html> references a letter sent by
+L<http://www.glyphweb.com/arda/f/fourthage.html> references a letter sent by
 Tolkien in 1958 in which he estimates approximately 6000 years have passed
 since the War of the Ring and the end of the Third Age.  (Thanks to Danny
 O'Brien from sending me this link).  I took this approximate as an exact
